Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(44)

Unified Diff: chrome/browser/policy/user_cloud_policy_manager_chromeos.h

Issue 11444029: Added UserPolicySigninService::FetchPolicyForSignedInUser(). (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: review feedback Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/policy/user_cloud_policy_manager_chromeos.h
diff --git a/chrome/browser/policy/user_cloud_policy_manager_chromeos.h b/chrome/browser/policy/user_cloud_policy_manager_chromeos.h
index 0104e5d55cdb980c330ed65aac9f537d650ab189..b3c12c37029afd55fcf4b8db62217a21c033807a 100644
--- a/chrome/browser/policy/user_cloud_policy_manager_chromeos.h
+++ b/chrome/browser/policy/user_cloud_policy_manager_chromeos.h
@@ -59,8 +59,9 @@ class UserCloudPolicyManagerChromeOS : public CloudPolicyManager,
private:
// Completion handler for the explicit policy fetch triggered on startup in
- // case |wait_for_policy_fetch_| is true.
- void OnInitialPolicyFetchComplete();
+ // case |wait_for_policy_fetch_| is true. |success| is true if the fetch was
+ // successful.
+ void OnInitialPolicyFetchComplete(bool success);
// Owns the store, note that CloudPolicyManager just keeps a plain pointer.
scoped_ptr<CloudPolicyStore> store_;
« no previous file with comments | « chrome/browser/policy/user_cloud_policy_manager.h ('k') | chrome/browser/policy/user_cloud_policy_manager_chromeos.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698